.. -*- rst -*-

Neurodriver
===========

Package Description
-------------------
Neurodriver is a Python implementation of a Local Processing Unit (LPU) with support
for various neuron and synapse models that can be used with the `Neurokernel
<https://github.com/neurokernel/neurokernel>`_ framework.

Prerequisites
-------------
Neurodriver requires Neurokernel and its various installation dependencies.

Installation
------------
First, install Neurokernel as indicated in its `README
<https://github.com/neurokernel/neurokernel/blob/master/README.rst>`_ file.

Next, download the latest Neurodriver as follows: ::

  git clone https://github.com/neurokernel/neurodriver.git

Install the package as follows: ::

  cd ~/neurodriver
  python setup.py develop

Authors & Acknowledgements
--------------------------
See the included `AUTHORS`_ file for more information.

.. _AUTHORS: AUTHORS.rst

License
-------
This software is licensed under the `BSD License
<http://www.opensource.org/licenses/bsd-license.php>`_.
See the included `LICENSE`_ file for more information.

.. _LICENSE: LICENSE.rst
